# PiBackbone
Backbone installer of core subsystems for Pi-based projects

# Getting Started
```
curl -fsSL https://short.iqt.org/pi | sh
```

# Assumptions
- Installing on a Raspberry Pi 3B+, 4, or Zero 2W
- Running Raspberry Pi OS
- Running as user `pi`
